@@ -7,9 +7,9 @@ import (
 	"fmt"
 	"net/http"
 
+	"carvel.dev/ytt/pkg/cmd"
 	"github.com/aws/aws-lambda-go/events"
 	"github.com/aws/aws-lambda-go/lambda"
-	"github.com/vmware-tanzu/carvel-ytt/pkg/cmd"
 )
 
 type HandlerFuncAdapter struct {
