@@ -7,12 +7,12 @@ import (
 	"os"
 	"testing"
 
+	cmdtpl "carvel.dev/ytt/pkg/cmd/template"
+	"carvel.dev/ytt/pkg/cmd/ui"
+	"carvel.dev/ytt/pkg/experiments"
+	"carvel.dev/ytt/pkg/files"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
-	cmdtpl "github.com/vmware-tanzu/carvel-ytt/pkg/cmd/template"
-	"github.com/vmware-tanzu/carvel-ytt/pkg/cmd/ui"
-	"github.com/vmware-tanzu/carvel-ytt/pkg/experiments"
-	"github.com/vmware-tanzu/carvel-ytt/pkg/files"
 )
 
 // TestMain is invoked when any tests are run in this package, *instead of* those tests being run directly.
