@@ -6,7 +6,7 @@ package template_test
 import (
 	"testing"
 
-	. "github.com/vmware-tanzu/carvel-ytt/pkg/template"
+	. "carvel.dev/ytt/pkg/template"
 )
 
 func TestAncestorsDeep(t *testing.T) {
