@@ -6,8 +6,8 @@ package texttemplate
 import (
 	"fmt"
 
-	"github.com/vmware-tanzu/carvel-ytt/pkg/filepos"
-	"github.com/vmware-tanzu/carvel-ytt/pkg/template"
+	"carvel.dev/ytt/pkg/filepos"
+	"carvel.dev/ytt/pkg/template"
 )
 
 type NodeRoot struct {
