@@ -6,7 +6,7 @@ package texttemplate
 import (
 	"fmt"
 
-	"github.com/vmware-tanzu/carvel-ytt/pkg/template"
+	"carvel.dev/ytt/pkg/template"
 )
 
 const (
