@@ -6,11 +6,11 @@ package yttlibrary
 import (
 	"fmt"
 
+	"carvel.dev/ytt/pkg/orderedmap"
+	"carvel.dev/ytt/pkg/template/core"
 	"github.com/k14s/starlark-go/starlark"
 	"github.com/k14s/starlark-go/starlarkstruct"
 	"github.com/k14s/starlark-go/syntax"
-	"github.com/vmware-tanzu/carvel-ytt/pkg/orderedmap"
-	"github.com/vmware-tanzu/carvel-ytt/pkg/template/core"
 )
 
 // NewAssertModule constructs a new instance of AssertModule, respecting the "validations" experiment flag.
