@@ -7,9 +7,9 @@ import (
 	"crypto/md5"
 	"fmt"
 
+	"carvel.dev/ytt/pkg/template/core"
 	"github.com/k14s/starlark-go/starlark"
 	"github.com/k14s/starlark-go/starlarkstruct"
-	"github.com/vmware-tanzu/carvel-ytt/pkg/template/core"
 )
 
 var (
