@@ -4,9 +4,9 @@
 package yttlibrary
 
 import (
+	"carvel.dev/ytt/pkg/template/core"
 	"github.com/k14s/starlark-go/starlark"
 	"github.com/k14s/starlark-go/starlarkstruct"
-	"github.com/vmware-tanzu/carvel-ytt/pkg/template/core"
 )
 
 var (
